import { defineMiddleware } from "../../core/middleware/index.js";
import { ApiContextStorage } from "./store.js";
import { formContentTypes, getAction } from "./utils.js";
import { ActionError } from "./virtual/shared.js";
const onRequest = defineMiddleware(async (context, next) => {
  const locals = context.locals;
  locals.getActionResult = () => Promise.resolve(void 0);
  const { request } = context;
  const contentType = request.headers.get("Content-Type");
  if (!formContentTypes.some((f) => contentType?.startsWith(f)))
    return next();
  const formData = await request.clone().formData();
  const actionPath = formData.get("_astroAction");
  if (typeof actionPath !== "string")
    return next();
  const actionPathKeys = actionPath.replace("/_actions/", "").split(".");
  const action = await getAction(actionPathKeys);
  let result;
  let actionError;
  try {
    result = await ApiContextStorage.run(context, () => action(formData));
  } catch (e) {
    if (!(e instanceof ActionError) || e.status === "INTERNAL_SERVER_ERROR") {
      throw e;
    }
    actionError = e;
  }
  locals.getActionResult = (actionFn) => {
    if (actionFn.toString() !== actionPath)
      return Promise.resolve(void 0);
    if (actionError)
      return Promise.reject(actionError);
    return Promise.resolve(result);
  };
  return next();
});
export {
  onRequest
};
