import { ApiContextStorage } from "./store.js";
import { getAction } from "./utils.js";
import { ActionError } from "./virtual/shared.js";
const POST = async (context) => {
  const { request, url } = context;
  if (request.method !== "POST") {
    return new Response(null, { status: 405 });
  }
  const actionPathKeys = url.pathname.replace("/_actions/", "").split(".");
  const action = await getAction(actionPathKeys);
  const contentType = request.headers.get("Content-Type");
  if (contentType !== "application/json") {
    throw new ActionError({
      status: "INTERNAL_SERVER_ERROR",
      message: "Called an action with a non-JSON body. To automatically convert form data requests to JSON, add `enhance: true` to your `defineAction()` config."
    });
  }
  const args = await request.clone().json();
  let result;
  try {
    result = await ApiContextStorage.run(context, () => action(args));
  } catch (e) {
    if (e instanceof ActionError) {
      return new Response(JSON.stringify(e), {
        status: 400,
        headers: {
          "Content-Type": "application/json"
        }
      });
    }
    throw e;
  }
  return new Response(JSON.stringify(result), {
    headers: {
      "Content-Type": "application/json"
    }
  });
};
export {
  POST
};
