import type { ZodError } from 'zod';
import type { MaybePromise } from '../utils.js';
type ActionErrorStatus = 'BAD_REQUEST' | 'UNAUTHORIZED' | 'FORBIDDEN' | 'NOT_FOUND' | 'INTERNAL_SERVER_ERROR';
export declare class ActionError extends Error {
    type: string;
    status: ActionErrorStatus;
    constructor(params: {
        message?: string;
        status: ActionErrorStatus;
    });
}
export declare class ValidationError extends ActionError {
    type: string;
    fieldErrors: ZodError;
    constructor(fieldErrors: ZodError);
}
export declare function safe<T>(actionResult: Promise<T>): Promise<{
    success: true;
    data: T;
} | {
    success: false;
    error: ActionError;
}>;
export declare function actionNameProps<T extends (...args: unknown[]) => MaybePromise<unknown>>(action: T): {
    readonly type: "hidden";
    readonly name: "_astroAction";
    readonly value: string;
};
export {};
