class ActionError extends Error {
  type = "AstroActionError";
  status = "INTERNAL_SERVER_ERROR";
  constructor(params) {
    super(params.message);
    this.status = params.status;
  }
}
class ValidationError extends ActionError {
  type = "AstroValidationError";
  fieldErrors;
  constructor(fieldErrors) {
    super({ message: "Failed to validate", status: "BAD_REQUEST" });
    this.fieldErrors = fieldErrors;
  }
}
async function safe(actionResult) {
  try {
    const data = await actionResult;
    return { success: true, data };
  } catch (e) {
    if (e instanceof ActionError) {
      return { success: false, error: e };
    }
    return {
      success: false,
      error: new ActionError({
        message: e instanceof Error ? e.message : "Unknown error",
        status: "INTERNAL_SERVER_ERROR"
      })
    };
  }
}
function actionNameProps(action) {
  return {
    type: "hidden",
    name: "_astroAction",
    value: action.toString()
  };
}
export {
  ActionError,
  ValidationError,
  actionNameProps,
  safe
};
